/*
 * utils.h - header-file for the functions in utils.c
 *
 * Copyright (C) 2004 - 2005 Andreas Czechanowski <a.cz @ gmx.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA  02111-1307  USA
 */

#ifndef __UTILS_H__
#define __UTILS_H__

/** separation character within path specifications */
#define DIRSEP ':'

/**
 * expands path when it begins with "~/" for home directory or "~user/" for
 * home directory of user.
 *
 * @param cp  string with pathname for input/output, must have
 *            enough space to hold the expanded name.
 */
void path_expand(char *cp);

/**
 * opens file, searches in the given list of paths.
 * Uses path_expand() to replace '~' with the $HOME direcrory
 *
 * @param path   colon-separated list of directories to search in
 * @param name   file to be opened
 * @param mode   may be "r" or "r+" if file should already exist.
 * @param where  if not NULL, the path+name is stored here upon success
 *
 * @return  FILE pointer as in fopen upon success, NULL if file not found
 */
FILE * pfopen(char *path, char *name, char *mode, char *where);

#endif /* __UTILS_H__ */
